@@ -9,7 +9,7 @@ use WebService::CIA::Source;
 
 @WebService::CIA::Source::DBM::ISA = ("WebService::CIA::Source");
 
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 sub new {
 
@@ -90,9 +90,9 @@ WebService::CIA::Source::DBM - an interface to a DBM copy of the CIA World Factb
 
   use WebService::CIA::Source::DBM;
   my $source = WebService::CIA::Source::DBM->new({
-                                           Source => 'factbook.dbm',
-                                           Mode   => 'read'
-                                          });
+                                                   Source => 'factbook.dbm',
+                                                   Mode   => 'read'
+                                                 });
 
 
 =head1 DESCRIPTION
@@ -127,11 +127,11 @@ Mode is optional and can be either "read" or "readwrite". It defaults to
 Retrieve a value from the DBM.
 
 C<$country_code> should be the FIPS 10-4 country code as defined in
-L<http://www.cia.gov/cia/publications/factbook/appendix/appendix-d.html>.
+L<https://www.cia.gov/cia/publications/factbook/appendix/appendix-d.html>.
 
 C<$field> should be the name of the field whose value you want to
 retrieve, as defined in
-L<http://www.cia.gov/cia/publications/factbook/docs/notesanddefs.html>.
+L<https://www.cia.gov/cia/publications/factbook/docs/notesanddefs.html>.
 (WebService::CIA::Parser also creates four extra fields: "URL", "URL - Print",
 "URL - Flag", and "URL - Map" which are the URLs of the country's Factbook
 page, the printable version of that page, a GIF map of the country, and a
@@ -172,7 +172,7 @@ This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 The CIA World Factbook's copyright information page
-(L<http://www.cia.gov/cia/publications/factbook/docs/contributor_copyright.html>)
+(L<https://www.cia.gov/cia/publications/factbook/docs/contributor_copyright.html>)
 states:
 
   The Factbook is in the public domain. Accordingly, it may be copied
